#
# spec file for package python-pymssql
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pymssql
Version:        2.3.2
Release:        1.1
Summary:        A simple database interface to MS-SQL for Python
License:        LGPL-2.1-only
Group:          Development/Languages/Python
URL:            https://pymssql.org
Source:         https://files.pythonhosted.org/packages/source/p/pymssql/pymssql-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 3.0.11}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  freetds-devel
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
BuildRequires:  python-rpm-macros
%python_subpackages

%description
pymssql is the Python language extension module that provides access to
Microsoft SQL Servers from Python scripts. It is compliant with Python
DB-API 2.0 Specification and works on most popular operating systems.

%prep
%setup -q -n pymssql-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

### Tests need access to a MSSQL-server
#%%check
#%%python_exec setup.py test

%files %{python_files}
%license LICENSE
%doc ChangeLog.rst README.rst
%{python_sitearch}/pymssql
%{python_sitearch}/pymssql-%{version}*-info

%changelog
* Sat Nov 23 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  * Update FreeTDS to 1.4.23.
  * Workaround setuptools-74.0 changes.
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Fix SP returning NULL (closes #441).
  * Update FreeTDS to 1.4.22 (closes #895).
  * Require Cython>3.0.10.
  * Add python 3.13 Linux wheels (closes #900).
* Sun Apr  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  General
  * Add python 3.12 support.
  * Add read_only parameter for connection.
  * Add encryption parameter to connect.
  * Add use_datetime2 parameter to connect.
  * Use utf-8 for connection properties.
  * Implement batching in executemany based on optional batch_size
    parameter. with default equal arraysize cursor attribute.
  * Fix DBAPI-2.0 compliance - DataError must be a subclass of
    DatabaseError.
  * Fix DBAPI-2.0 compliance: rename batchsize cursor attribute to
    arraysize.
  * Implement DATETIMEOFFSET handling for stored procedures.
  * Implement DATETIMEOFFSET handling for insert and select queries
  * Return instance of datetime.datetime on select from
    SQLDATETIM4, SQLDATETIME, SQLDATETIME2 columns.
  Bug fixes
  * Fix SQLDATETIME2 handling in convert_python_value().
  * Use four digits for the year in SP args binding.
  * Fix convert_python_value to work with datetime.date.
  * Check if C compiler is installed if check for clock_gettime
    fails.
  * Add missing charset parameter in the _substitute_params method
    when calling ensure_bytes.
  * Fix empty, zero or None parameter substitution.
  Internals
  * Add tests for fetchall(), fetchmany(), fetchone() and next()
    with SP.
  * Require Cython>3.0.7.
  * Use Cython 3 for compilation.
  * Add SQLTIME and SQLDATETIME2 to convert_python_value.
  * Use dbanydatecrack() function instead of dbdatecrack().
  * Replace DEF with cdef enum for buffer array size
  * Remove references to tox.
  * Add tests for timeout in wait callback.
  * Clean up some legacy FreeTDS shims.
  * Add tests for tds_version parameter.
  * Move check for clock_gettime to dev/ccompiler.py.
  * Remove some Python2 remnants.
  * Move FreeTDS version from workflow files to pyproject.toml.
  * Move exceptions into separate module.
  * Use strftime for date & time conversion.
  * Simplify parameters quoting.
  * Add tests for _quote_simple_value.
* Thu Dec 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.11
  General
  * Add datetime.date to SQLDATE conversion.
  * Add encryption parameter to connect.
  Bug fixes
  * Fix version parsing in development.
  * Add missing charset parameter when formatting query.
  * Use four digits for the year in SP args binding.
  * Fix convert_python_value to work with datetime.date.
* Mon Oct 30 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.10
  * Add python 3.12 support.
  * Do not try to drop temporary tables in clear_db().
  * test_sqlalchemy: update for compatibility with SQLAlchemy >2.0.
- Update to version 2.2.9
  * Update changelog.
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.8:
  * Compatibility with Cython.
  * Fix build on Alpine Linux (fix #762).
  * Fill in result description in cursor.callproc (fix #772).
  * Add explicit link to krb5 (fix #776)
  * Added bytes and bytearray to support bulk_copy types, thanks
    to steve-strickland (#756).
  * Fix UnicodeEncodeError for non-ascii database name (#484).
  * Fix pymssql.Binary (#504).
  * On macOS check for FreeTDS in homebrew prefix when building.
  * Some documentation changes.
  * Drop support for Python2 and Python3 < 3.6.
  * Fixed a deadlock caused by a missing release of GIL (#540),
  * Prevents memory leak on login failure. Thanks to caogtaa and
    Simon.StJG (PR-690).
  * Fix check for TDS version (#652 and #669).
* Wed Oct 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.5
  * Revert deprecation
  * Support Python-3.8. Update tests for Python-3.8 compatibility.
  * Use correct language level for building Cython extension.
  * Fix FreeTDS version checks. Add check for version 7.4.
  * Drop bundled FreeTDS-0.95 binaries.
* Tue Oct  2 2018 mardnh@gmx.de
- Convert to singlespec
- Update to version 2.1.4
* Fri Apr 10 2015 hanke@rzg.mpg.de
- Update to version 2.1.1
  * Buildrequire python-setuptools-git
* Thu Dec  5 2013 termim@gmail.com
- Update to release version (2.0.0)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jun 19 2013 speilicke@suse.com
- Many spec fixes
* Wed Jun 12 2013 termim@gmail.com
- Initial checkin
